#!/usr/bin/gnuplot

G = 6.67e-11
M_S = 1.989e30
M_E = 5.972e24
au = 1.496e11
yr = 365.25*86400.0
cm = 1.e-2
g = 1.e-3

dt = 0.314159
P = 20*dt

f(x) = x/1e-6
g(m) = m*M_S/M_E

n(r) = sqrt(G*M_S/r**3)
dadt(r,m,Gamma_cgs) = 2*Gamma_cgs*g*cm**2/(r*au*n(r*au)*m*M_S) / (1.e-6*au/yr)

r = 1*au
print "r = ", r, " m"
print "n = ", n(r), " rad s^-1 = ", n(r)*yr, " rad yr^-1"

########################################################################

set term png small
set out "dadt14.png"

set xl "m [M_E]"
set yl "r [au]"
set cbl "da/dt [10^{-6} au/yr]"

x1=-0.05
x2=1.05
set xr [x1:x2]
y1=0.20
y2=1.80
set yr [y1:y2]
c1=-4.0
c2=4.0
set cbr [c1:c2]

set palette defined (\
  (c1  -c1)/(c2-c1) '#aa00ff',\
  (-1.5-c1)/(c2-c1) 'blue'   ,\
  (-0.5-c1)/(c2-c1) 'cyan'  ,\
  ( 0.0-c1)/(c2-c1) 'white' ,\
  (+0.5-c1)/(c2-c1) 'orange',\
  (c2  -c1)/(c2-c1) 'red'    \
  )

set colorbox
set zeroaxis
set pm3d map

lw=0.5
ps=1.5
set style line 1 pt 5 ps ps lc palette z lw lw
set style line 2 pt 4 ps ps lc 'gray'  lw lw
set style line 3 pt 4 ps ps lc 'black' lw lw dt 2

sp \
  "massdataGamma0.out"  u (g($2)):1:(dadt($1,$2,$7)),\
  "../out_META/5/dadt.out" u (g($4)):2:(f($3)) not w l  ls 2,\
  "../out_META/5/dadt.out" u (g($4)):2:(f($3)) not w p  ls 1,\
  "../out_META/5/dadt.out" u (g($4)):2:(f($3)) not w p  ls 2,\

q



